pub struct Ridge {}Expand description
This is the Ridge function.
The function is borrowed from here. Although the function accepts a vector with an arbitrary number of inputs, this is what it looks like in 2D: